"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DdlBuilderBase = void 0;
const domain_1 = require("../../../query/domain");
const lambdaorm_base_1 = require("lambdaorm-base");
class DdlBuilderBase {
    // eslint-disable-next-line no-useless-constructor
    constructor(source, mapping, dialect, helper) {
        this.source = source;
        this.mapping = mapping;
        this.dialect = dialect;
        this.helper = helper;
    }
    objects() {
        const text = this.dialect.ddl(lambdaorm_base_1.SentenceAction.objects);
        return new domain_1.Query({ action: lambdaorm_base_1.SentenceAction.objects, dialect: this.source.dialect, source: this.source.name, sentence: text, entity: '' });
    }
    tables(names) {
        let text = this.dialect.ddl(lambdaorm_base_1.SentenceAction.tables);
        text = text.replace('{names}', names.map(p => this.dialect.string(p)).join(','));
        return new domain_1.Query({ action: lambdaorm_base_1.SentenceAction.tables, dialect: this.source.dialect, source: this.source.name, sentence: text, entity: '' });
    }
    views(names) {
        let text = this.dialect.ddl(lambdaorm_base_1.SentenceAction.views);
        text = text.replace('{names}', names.map(p => this.dialect.string(p)).join(','));
        return new domain_1.Query({ action: lambdaorm_base_1.SentenceAction.views, dialect: this.source.dialect, source: this.source.name, sentence: text, entity: '' });
    }
    primaryKeys(tableNames) {
        let text = this.dialect.ddl(lambdaorm_base_1.SentenceAction.primaryKeys);
        text = text.replace('{tableNames}', tableNames.map(p => this.dialect.string(p)).join(','));
        return new domain_1.Query({ action: lambdaorm_base_1.SentenceAction.primaryKeys, dialect: this.source.dialect, source: this.source.name, sentence: text, entity: '' });
    }
    uniqueKeys(tableNames) {
        let text = this.dialect.ddl(lambdaorm_base_1.SentenceAction.uniqueKeys);
        text = text.replace('{tableNames}', tableNames.map(p => this.dialect.string(p)).join(','));
        return new domain_1.Query({ action: lambdaorm_base_1.SentenceAction.uniqueKeys, dialect: this.source.dialect, source: this.source.name, sentence: text, entity: '' });
    }
    foreignKeys(tableNames) {
        let text = this.dialect.ddl(lambdaorm_base_1.SentenceAction.foreignKeys);
        text = text.replace('{tableNames}', tableNames.map(p => this.dialect.string(p)).join(','));
        return new domain_1.Query({ action: lambdaorm_base_1.SentenceAction.foreignKeys, dialect: this.source.dialect, source: this.source.name, sentence: text, entity: '' });
    }
    indexes(tableNames) {
        let text = this.dialect.ddl(lambdaorm_base_1.SentenceAction.indexes);
        text = text.replace('{tableNames}', tableNames.map(p => this.dialect.string(p)).join(','));
        return new domain_1.Query({ action: lambdaorm_base_1.SentenceAction.indexes, dialect: this.source.dialect, source: this.source.name, sentence: text, entity: '' });
    }
    sequences() {
        const text = this.dialect.ddl(lambdaorm_base_1.SentenceAction.sequences);
        return new domain_1.Query({ action: lambdaorm_base_1.SentenceAction.sequences, dialect: this.source.dialect, source: this.source.name, sentence: text, entity: '' });
    }
}
exports.DdlBuilderBase = DdlBuilderBase;
//# sourceMappingURL=DdlBuilderBase.js.map